#
##  1、什么是apin

apin是一个无需写代码，就可以完成接口自动化测试的框架，只需要通过json或yaml文件编写非常简洁的用例数据，即可完成接口自动化测试，并生成自动化测试报告。旨在帮助更多不会写代码的小伙伴掌握接口自动化测试的能力。框架使用起来非常简单，易上手，只需要几个小时就能掌握！


- 目前只是第一个版本，还存在一些问题和功能，后续会继续完善，在使用的过程中发现问题，可以通过邮箱反馈

- 开发者：柠檬班-木森
- email：musen_nmb@qq.com
## 2、安装apin

apin是基于python3.6开发的，安装前请确认你的python版本>3.6

- **安装命令**

    `
    pip install apin
    `
    
## 3、使用文档：https://apin.readthedocs.io/en/latest/